@@ -575,6 +575,22 @@ class IP:
                 unique_deps.append(dep)
         return unique_deps
     
+    def get_ordered_install_deps(self):
+        deps_list = []
+        self.dependencies.sort(key= get_key)
+        for dep in self.dependencies:
+            common.dbg(f"Processing dependency '{dep.vendor}/{dep.target_ip}'")
+            if dep.target_ip_model.is_local:
+                continue
+            deps_deps_list = dep.target_ip_model.get_ordered_deps()
+            deps_list += deps_deps_list
+            deps_list.append(dep.target_ip_model)
+        unique_deps = []
+        for dep in deps_list:
+            if dep not in unique_deps:
+                unique_deps.append(dep)
+        return unique_deps
+    
     def get_deps_to_install(self):
         deps = []
         for dep in self.dependencies:
