@@ -214,11 +214,11 @@ def build_parser():
     parser_repeat.add_argument("cmd",  help='Command to be repeated', choices=repeat_commands)
     parser_repeat.add_argument('-b', "--bwrap", help='Does not run command, only creates bash script and packages project.', action="store_true", default=False , required=False)
     
-    parser_sim = subparsers.add_parser('regr', help=help_text.regr_help_text, add_help=False)
-    parser_sim.add_argument('ip'         , help='Target IP')
-    parser_sim.add_argument('regr'       , help='Regression to be run.  For Test Bench IPs with multiple Test Suites, the suite must be specified. Ex: `mio regr my_ip apbxc.sanity`')
-    parser_sim.add_argument('-a', "--app", help='Specifies which simulator to use: viv, mdc, vcs, xcl, qst, riv.', choices=simulators , required=False)
-    parser_sim.add_argument('-d', "--dry", help='Compiles and elaborates target IP but only prints out the tests that would be run.', action="store_true", default=False , required=False)
+    parser_regr = subparsers.add_parser('regr', help=help_text.regr_help_text, add_help=False)
+    parser_regr.add_argument('ip'         , help='Target IP')
+    parser_regr.add_argument('regr'       , help='Regression to be run.  For Test Bench IPs with multiple Test Suites, the suite must be specified. Ex: `mio regr my_ip apbxc.sanity`')
+    parser_regr.add_argument('-a', "--app", help='Specifies which simulator to use: viv, mdc, vcs, xcl, qst, riv.', choices=simulators , required=False)
+    parser_regr.add_argument('-d', "--dry", help='Compiles and elaborates target IP but only prints out the tests that would be run.', action="store_true", default=False , required=False)
     
     parser_clean = subparsers.add_parser('clean', help=help_text.clean_help_text, add_help=False)
     parser_clean.add_argument('ip'          , help='Target IP'                                                            )
