@@ -462,9 +462,10 @@ def compile_flist(vendor, name, flist_path, deps, sim_job, local, licensed=True)
     
     if sim_job.is_regression:
         ip_dir_name = f"{sim_job.vendor}__{sim_job.ip}__{sim_job.regression_name}"
-        common.create_dir(cfg.sim_output_dir + "/" + sim_str + "/regr_wd/" + ip_dir_name)
-        common.create_dir(cfg.sim_output_dir + "/" + sim_str + "/regr_wd/" + ip_dir_name + "/" + sim_job.regression_timestamp)
-        sim_out  =        cfg.sim_output_dir + "/" + sim_str + "/regr_wd/" + ip_dir_name + "/" + sim_job.regression_timestamp
+        if sim_job.simulator != common.simulators_enum.METRICS:
+            common.create_dir(cfg.sim_output_dir + "/" + sim_str + "/regr_wd/" + ip_dir_name)
+            common.create_dir(cfg.sim_output_dir + "/" + sim_str + "/regr_wd/" + ip_dir_name + "/" + sim_job.regression_timestamp)
+        sim_out = cfg.sim_output_dir + "/" + sim_str + "/regr_wd/" + ip_dir_name + "/" + sim_job.regression_timestamp
     else:
         sim_out = cfg.sim_output_dir + "/" + sim_str + "/sim_wd"
     
@@ -785,7 +786,7 @@ def do_simulate(ip, sim_job, wd):
             # TODO Implement waves file for vcs
             pass
         elif sim_job.simulator == common.simulators_enum.METRICS:
-            arg_list.append(f"-waves {test_result_dir}.fst")
+            arg_list.append(f"-waves {test_result_dir}.vcd")
         elif sim_job.simulator == common.simulators_enum.XCELIUM:
             # TODO Implement waves file for xcelium
             pass
@@ -894,9 +895,9 @@ def do_simulate(ip, sim_job, wd):
         if not sim_job.dry_run:
             common.move_file(f"{cfg.project_dir}/_downloaded_{mtr_simulation_log_path}", simulation_log_path)
             if sim_job.waves:
-                common.remove_file(f"{cfg.project_dir}/_downloaded_{test_result_dir}.fst")
-                sim_job.bwrap_commands += launch_eda_bin(cfg.metrics_home + "/mdc", ["download", f"{test_result_dir}.fst"], wd=cfg.project_dir, dry_run=sim_job.dry_run)
-                common.move_file(f"{cfg.project_dir}/_downloaded_{test_result_dir}.vcd", f"{tests_results_path}/waves.fst")
+                common.remove_file(f"{cfg.project_dir}/_downloaded_{test_result_dir}.vcd")
+                sim_job.bwrap_commands += launch_eda_bin(cfg.metrics_home + "/mdc", ["download", f"{test_result_dir}.vcd"], wd=cfg.project_dir, dry_run=sim_job.dry_run)
+                common.move_file(f"{cfg.project_dir}/_downloaded_{test_result_dir}.vcd", f"{tests_results_path}/waves.vcd")
         
     elif sim_job.simulator == common.simulators_enum.XCELIUM:
         arg_list += xcelium_default_simulation_args
